@@ -21,23 +21,31 @@ class NWPDataSource(ZarrDataSource):
     NWP Data Source (Numerical Weather Predictions)
 
     Attributes:
-      _data: xr.DataArray of Numerical Weather Predictions, opened by open().
-        x is left-to-right.
-        y is top-to-bottom.
-        Access using public nwp property.
-      consolidated: Whether or not the Zarr store is consolidated.
-      channels: The NWP forecast parameters to load. If None then don't filter.
-        The available params are:
-            t     : Temperature in Kelvin.
-            dswrf : Downward short-wave radiation flux in W/m^2 (irradiance).
-            prate : Precipitation rate in kg/m^2/s.
-            r     : Relative humidty in %.
-            sde   : Snow depth in meters.
-            si10  : 10-meter wind speed in m/s.
-            vis   : Visibility in meters.
-            lcc   : Low-level cloud cover in %.
-            mcc   : Medium-level cloud cover in %.
-            hcc   : High-level cloud cover in %.
+        _data: xr.DataArray of Numerical Weather Predictions, opened by open().
+            x is left-to-right.
+            y is bottom-to-top.
+        consolidated: Whether or not the Zarr store is consolidated.
+        channels: The NWP forecast parameters to load. If None then don't filter.
+            See:  http://cedadocs.ceda.ac.uk/1334/1/uk_model_data_sheet_lores1.pdf
+            All of these params are "instant" (i.e. a snapshot at the target time,
+            not accumulated over some time period).  The available params are:
+                cdcb  : Height of lowest cloud base > 3 oktas, in meters above surface.
+                lcc   : Low-level cloud cover in %.
+                mcc   : Medium-level cloud cover in %.
+                hcc   : High-level cloud cover in %.
+                sde   : Snow depth in meters.
+                hcct  : Height of convective cloud top, meters above surface.
+                dswrf : Downward short-wave radiation flux in W/m^2 (irradiance) at surface.
+                dlwrf : Downward long-wave radiation flux in W/m^2 (irradiance) at surface.
+                h     : Geometrical height, meters.
+                t     : Air temperature at 1 meter above surface in Kelvin.
+                r     : Relative humidty in %.
+                dpt   : Dew point temperature in Kelvin.
+                vis   : Visibility in meters.
+                si10  : Wind speed in meters per second, 10 meters above surface.
+                wdir10: Wind direction in degrees, 10 meters above surface.
+                prmsl : Pressure reduce to mean sea level in Pascals.
+                prate : Precipitation rate at the surface in kg/m^2/s.
     """
 
     channels: Optional[Iterable[str]] = NWP_VARIABLE_NAMES
@@ -66,13 +74,13 @@ class NWPDataSource(ZarrDataSource):
         """
         Open NWP data
 
-        We don't want to open_sat_data in __init__.
+        We don't want to open_nwp() in __init__.
         If we did that, then we couldn't copy NWPDataSource
         instances into separate processes.  Instead,
         call open() _after_ creating separate processes.
         """
         data = self._open_data()
-        self._data = data["UKV"].sel(variable=list(self.channels))
+        self._data = data.sel(variable=list(self.channels))
 
     def _open_data(self) -> xr.DataArray:
         return open_nwp(self.zarr_path, consolidated=self.consolidated)
@@ -101,6 +109,7 @@ class NWPDataSource(ZarrDataSource):
         start_hourly = start_dt.floor("H")
         end_hourly = end_dt.ceil("H")
 
+        # TODO: Issue #398: Use NWP init time closest to t0.
         init_time_i = np.searchsorted(self.data.init_time, start_hourly.to_numpy(), side="right")
         init_time_i -= 1  # Because searchsorted() gives the index to the entry _after_.
         init_time = self.data.init_time.values[init_time_i]
@@ -131,7 +140,10 @@ class NWPDataSource(ZarrDataSource):
             nwp = self._open_data()
         else:
             nwp = self._data
-        target_times = nwp["init_time"] + nwp["step"][:3]
+        # We need to return the `target_times` (the times the NWPs are _about_).
+        # The `target_time` is the `init_time` plus the forecast horizon `step`.
+        # `step` is an array of timedeltas, so we can just add `init_time` to `step`.
+        target_times = nwp["init_time"] + nwp["step"]
         target_times = target_times.values.flatten()
         target_times = np.unique(target_times)
         target_times = np.sort(target_times)
@@ -144,16 +156,15 @@ class NWPDataSource(ZarrDataSource):
         return 60
 
 
-def open_nwp(zarr_path: str, consolidated: bool) -> xr.Dataset:
+def open_nwp(zarr_path: str, consolidated: bool) -> xr.DataArray:
     """
     Open The NWP data
 
     Args:
         zarr_path: zarr_path must start with 'gs://' if it's on GCP.
-        consolidated: consolidate the zarr file?
-
-    Returns: nwp data
+        consolidated: Is the Zarr metadata consolidated?
 
+    Returns: NWP data.
     """
     _LOG.debug("Opening NWP data: %s", zarr_path)
     utils.set_fsspec_for_multiprocess()
@@ -161,9 +172,31 @@ def open_nwp(zarr_path: str, consolidated: bool) -> xr.Dataset:
         zarr_path, engine="zarr", consolidated=consolidated, mode="r", chunks=None
     )
 
-    # Sanity check.
-    # TODO: Replace this with
-    # pandas.core.indexes.base._is_strictly_monotonic_increasing()
-    assert utils.is_monotonically_increasing(nwp.init_time.astype(int))
-    assert utils.is_unique(nwp.init_time)
-    return nwp
+    ukv = nwp["UKV"]
+
+    # Sanity checks.
+    # If there are any duplicated init_times then drop the duplicated init_times:
+    init_time = pd.DatetimeIndex(ukv["init_time"])
+    if not init_time.is_unique:
+        n_duplicates = init_time.duplicated().sum()
+        _LOG.warning(f"NWP Zarr has {n_duplicates:,d} duplicated init_times.  Fixing...")
+        ukv = ukv.drop_duplicates(dim="init_time")
+        init_time = pd.DatetimeIndex(ukv["init_time"])
+
+    # If any init_times are not monotonic_increasing then drop the out-of-order init_times:
+    if not init_time.is_monotonic_increasing:
+        total_n_out_of_order_times = 0
+        _LOG.warning("NWP Zarr init_time is not monotonic_increasing.  Fixing...")
+        while not init_time.is_monotonic_increasing:
+            diff = np.diff(init_time.view(int))
+            out_of_order = np.where(diff < 0)[0]
+            total_n_out_of_order_times += len(out_of_order)
+            out_of_order = init_time[out_of_order]
+            ukv = ukv.drop_sel(init_time=out_of_order)
+            init_time = pd.DatetimeIndex(ukv["init_time"])
+        _LOG.info(f"Fixed {total_n_out_of_order_times:,d} out of order init_times.")
+
+    assert init_time.is_unique
+    assert init_time.is_monotonic_increasing
+
+    return ukv
